%define module	gmpy
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so %{python3_sitearch}/.*\\.so

Summary:	Python interface to GMP
Name:		python-%{module}
Version:	1.17
Release:	%mkrel 15
Source0:	https://pypi.io/packages/g/%{module}/%{module}-%{version}.zip
License: 	LGPLv2.1
Group: 		Development/Python
Url: 		https://github.com/aleaxit/gmpy
# GMP versions before 4.2.4 have a bug that cause gmpy to segfault.
Requires:	libgmp >= 4.2.4
BuildRequires:	libgmp-devel >= 4.2.4

%description
The General Multiprecision PYthon project (GMPY) focuses on
Python-usable modules providing multiprecision arithmetic
functionality to Python programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.

%package -n python3-%{module}
Summary:	Python 3 interface to GMP
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
The General Multiprecision PYthon project (GMPY) focuses on
Python 3 usable modules providing multiprecision arithmetic
functionality to Python 3 programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python 3 modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.


%prep
%setup -q -n %{module}-%{version}

%build
find -name .svn | xargs rm -rf
CFLAGS="%{optflags}" %{py3_build}

%install
%py3_install
chmod 755 %{buildroot}%{python3_sitearch}/gmpy*.so

%check
# Make python see the library that we have just compiled
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir

cd test
%{__python3} gmpy_test.py

%files -n python3-%{module}
%doc README doc/ test/
%{python3_sitearch}/gmpy*.so
%{python3_sitearch}/gmpy-%{version}-py*.egg-info



%changelog
* Sun Feb 16 2020 umeabot <umeabot> 1.17-15.mga8
+ Revision: 1535634
- Mageia 8 Mass Rebuild

* Sun Oct 13 2019 tv <tv> 1.17-14.mga8
+ Revision: 1452607
- rebuild for python-3.8
- drop python2 subpkg

* Wed Jan 09 2019 shlomif <shlomif> 1.17-13.mga7
+ Revision: 1353184
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.17-12.mga7
+ Revision: 1300486
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Fix Source0 and URL links

* Tue Mar 20 2018 kekepower <kekepower> 1.17-11.mga7
+ Revision: 1210815
- Renamed python-gmpy to python2-gmpy

* Sat Aug 05 2017 pterjan <pterjan> 1.17-10.mga7
+ Revision: 1135438
- Rebuild for python 3.6

* Fri Feb 12 2016 umeabot <umeabot> 1.17-9.mga6
+ Revision: 958602
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 tv <tv> 1.17-8.mga6
+ Revision: 887503
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 1.17-7.mga5
+ Revision: 748654
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.17-6.mga5
+ Revision: 728576
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.17-5.mga5
+ Revision: 688055
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 1.17-4.mga5
+ Revision: 628662
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.17-3.mga4
+ Revision: 543490
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.17-2.mga4
+ Revision: 498697
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 11 2013 philippem <philippem> 1.17-1.mga4
+ Revision: 477791
- update to 1.17, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.16-2.mga3
+ Revision: 378921
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.16-1.mga3
+ Revision: 324744
- new version 1.16

* Thu Jul 26 2012 kamil <kamil> 1.15-1.mga3
+ Revision: 274418
- new version 1.15
- update Source0

* Thu Jul 26 2012 kamil <kamil> 1.14-2.mga3
+ Revision: 274413
- adapt for Mageia
- imported package python-gmpy


* Mon Dec 13 2010 Lev Givon <lev@mandriva.org> 1.14-1mdv2011.0
+ Revision: 620654
- Update to 1.14.

* Sat Nov 06 2010 Funda Wang <fwang@mandriva.org> 1.12-2mdv2011.0
+ Revision: 594037
- rebuld for py 2.7

* Mon Jul 19 2010 Lev Givon <lev@mandriva.org> 1.12-1mdv2011.0
+ Revision: 554995
- Update to 1.12.

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 1.11-1mdv2010.1
+ Revision: 503561
- New version 1.11
- rebuild for new gmp

* Sun Dec 27 2009 Frederik Himpe <fhimpe@mandriva.org> 1.10-1mdv2010.1
+ Revision: 482849
- Update to new version 1.10

* Wed Apr 01 2009 Lev Givon <lev@mandriva.org> 1.04-1mdv2010.0
+ Revision: 363390
- Update to 1.04.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 1.03-1mdv2009.0
+ Revision: 233834
- Update to 1.03.

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.01-3mdv2008.1
+ Revision: 136448
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Sun Jan 21 2007 Nicolas Lécureuil <neoclust@mandriva.org> 1.01-3mdv2007.0
+ Revision: 111518
- Rebuicl for new python
- import python-gmpy-1.01-2mdk

* Thu May 04 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.01-2mdk
- Add BuildRequires
- Fix mkrel for rpmbuildupdate

* Wed May 03 2006 Lev Givon <lev@columbia.edu> 1.01-1mdk
- Initial Mandriva package.

